@@ -89,7 +89,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         page_vbox = gu.hig_dlg_vbox()
         self.append_page(page_vbox, gtk.Label(_("User")))
 
-        box, category_vbox = gu.hig_category_vbox(_("Users voice"))
+        box, category_vbox = gu.hig_category_vbox(_("User's voice"))
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
@@ -179,12 +179,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
-        self.g_web_browser = gtk.Entry()
-        self.g_web_browser.set_text(self.get_string("config/web_browser"))
-        self.g_web_browser.connect('changed', self.on_changed)
-        box = gu.hig_label_widget(_("_Web browser:"), self.g_web_browser, sizegroup)
-        category_vbox.pack_start(box)
-
         self.g_mail_program = gtk.Entry()
         self.g_mail_program.set_text(self.get_string("config/mua"))
         self.g_mail_program.connect('changed', self.on_changed)
@@ -249,7 +243,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         self.g_wav_player.entry.connect('changed', self.on_changed)
         button = gtk.Button(_("Test"))
         button.connect('clicked', self.test_wav_player)
-        box = gu.hig_label_widget(".wav file player",
+        box = gu.hig_label_widget(_(".wav file player"),
                                   [self.g_wav_player, button],
                                   sizegroup)
         category_vbox.pack_start(box)
@@ -260,7 +254,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         self.g_midi_player.entry.connect('changed', self.on_changed)
         button = gtk.Button(_("Test"))
         button.connect('clicked', self.test_midi_player)
-        box = gu.hig_label_widget(".midi file player",
+        box = gu.hig_label_widget(_(".midi file player"),
                                   [self.g_midi_player, button],
                                   sizegroup)
         category_vbox.pack_start(box)
@@ -326,17 +320,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         page_vbox.pack_start(box, False)
 
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        self.g_wav_player = gtk.Combo()
-        self.g_wav_player.set_popdown_strings(('/usr/bin/aplay',
-                                               '/usr/bin/play'))
-        self.g_wav_player.entry.set_text(cfg.get_string('sound/wav_player'))
-        self.g_wav_player.entry.connect('changed', self.on_changed)
-        button = gtk.Button(_("Test"))
-        button.connect('clicked', self.test_wav_player)
-        box = gu.hig_label_widget(".wav file player",
-                                  [self.g_wav_player, button],
-                                  sizegroup)
-        category_vbox.pack_start(box)
 
         self.g_midi_player = gtk.Combo()
         self.g_midi_player.set_popdown_strings(('/usr/bin/timidity -idqq %s',
@@ -352,7 +335,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
 
         box, category_vbox = gu.hig_category_vbox(_("Sound setup"))
         page_vbox.pack_start(box)
-        txt = gtk.Label(_("""Solfege has two ways to play music. It is recommended to use Windows multimedia output. An external midiplayer is only useful if your soundcard lack a hardware synth, and you have to use a program like timidity to play the music."""))
+        txt = gtk.Label(_("""Solfege has two ways to play midi files. It is recommended to use Windows multimedia output. An external midiplayer can be useful if your soundcard lacks a hardware synth, in which case you have to use a program like timidity to play the music."""))
         txt.set_line_wrap(1)
         txt.set_justify(gtk.JUSTIFY_FILL)
         txt.set_alignment(0.0, 0.0)
@@ -385,12 +368,12 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         self.g_midiplayer_radio.connect('clicked', self.on_changed)
         self.g_synth_num.connect('changed', self.on_changed)
         self.g_device_radio.connect('clicked', self.on_changed)
-    def test_wav_player(self, w):
-        app.run_external_program(self.g_wav_player.entry.get_text(),
-                 'lesson-files/share', 'fifth-small-220.00.wav')
     def test_midi_player(self, w):
         app.run_external_program(self.g_midi_player.entry.get_text(),
                         'lesson-files/share', 'fanfare.midi')
+    def test_wav_player(self, w):
+        app.run_external_program(self.g_wav_player.entry.get_text(),
+                        'lesson-files/share', 'fifth-small-220.00.wav')
     def on_sound_test(self, w):
         mpd.play_music(r"""
         \staff\relative c{
@@ -462,7 +445,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
             self.set_bool('gui/mainwin_user_resizeable',
                           self.g_mainwin_user_resizeable.get_active())
             self.m_app.m_ui.set_resizable(self.get_bool('gui/mainwin_user_resizeable'))
-            self.set_string("config/web_browser", self.g_web_browser.get_text())
             self.set_string("config/mua", self.g_mail_program.get_text())
         if pagenum == 3:
             self.set_bool('config/picky_on_new_question',
@@ -513,8 +495,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
                 # we set the spin just in case m_devnum was changed by the
                 # soundcard setup code, if it was out of range
                 self.g_synth_num.set_value(soundcard.synth.m_devnum)
-            self.set_string("sound/wav_player",
-                            self.g_wav_player.entry.get_text())
             self.set_string("sound/midi_player",
                             self.g_midi_player.entry.get_text())
         if pagenum == -1:
