@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'dictation',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("_Dictation")),
-    'icon': 'graphics/dictation24.png',
+    'stock-icon': 'solfege-dictation',
     'toolbar': 6,
 }
 import exercise_setup
@@ -252,10 +252,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def create_pixmap_button(self):
         im = gtk.Image()
-        im.set_from_file(os.path.join("graphics", "rhythm-c4.png"))
+        im.set_from_stock("solfege-rhythm-c4", gtk.ICON_SIZE_LARGE_TOOLBAR)
+        im.show()
         btn = gtk.Button()
         btn.add(im)
-        im.show()
         return btn
     def on_start_practise(self):
         self.g_play.grab_focus()
