@@ -31,7 +31,7 @@ if __name__ == 'idbyname':
     import i18n
     i18n.setup_srcdir()
 
-import gtk, gnome
+import gtk, gnome, gobject
 import gu, widgets
 import abstract, const, mpd, mpd.musicdisplayer
 import utils
@@ -62,7 +62,7 @@ class Teacher(abstract.LessonbasedTeacher):
         UI will never call this function unless we have a usable lessonfile.
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -130,7 +130,7 @@ class Gui(abstract.LessonbasedGui):
         self.add_random_transpose_gui()
         # -----------------------------------------
         self.g_select_questions_category_box, category_box= gu.hig_category_vbox(
-            _("Select questions to ask"))
+            _("Questions to ask"))
         self.config_box.pack_start(self.g_select_questions_category_box, True)
         self.g_select_questions = widgets.QuestionNameCheckButtonTable(self.m_t)
         self.g_select_questions.initialize(4, 0)
@@ -165,7 +165,7 @@ class Gui(abstract.LessonbasedGui):
                       self.m_t.m_P.header.labelformat, self.on_click)
         else:
             self.g_bb.initialize(0, 0)
-        if self.m_t.m_P.header.questions_selectable:
+        if self.m_t.m_P and self.m_t.m_P.header.questions_selectable:
             self.g_bb.ask_for_names_changed()
     def update_select_question_buttons(self):
         if self.m_t.m_P and self.m_t.m_P.header.questions_selectable:
@@ -188,7 +188,8 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_P:
             self.g_new.set_sensitive(True)
             self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
-            if self.m_t.m_P.header.musicformat == 'chord':
+            if filter(lambda q: q['music'].m_musictype == 'chord',
+                      self.m_t.m_P.m_questions):
                 self.g_repeat_arpeggio.show()
             else:
                 self.g_repeat_arpeggio.hide()
@@ -334,7 +335,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_new.grab_focus()
         self.m_t.m_statistics.reset_session()
         self.g_music_displayer.clear()
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New' to begin.")))
     def on_end_practise(self):
         self.m_t.end_practise()
