@@ -37,13 +37,13 @@ class EditorIconFactory(BaseIconFactory):
     def __init__(self, widget, datadir):
         BaseIconFactory.__init__(self, widget, datadir)
         icons = {'solfege-icon': "graphics/solfege.png", #FIXME new icon
-            'solfege-sharp': "graphics/sharp.svg",
-            'solfege-double-sharp': "graphics/double-sharp.svg",
-            'solfege-flat': "graphics/flat.svg",
-            'solfege-double-flat': "graphics/double-flat.svg",
-            'solfege-natural': "graphics/natural.svg",
-            'solfege-erase': "graphics/erase.svg",
-            'solfege-notehead': "graphics/notehead.svg"}
+            'solfege-sharp': "graphics/sharp.png",
+            'solfege-double-sharp': "graphics/double-sharp.png",
+            'solfege-flat': "graphics/flat.png",
+            'solfege-double-flat': "graphics/double-flat.png",
+            'solfege-natural': "graphics/natural.png",
+            'solfege-erase': "graphics/erase.png",
+            'solfege-notehead': "graphics/notehead.png"}
         self.add_icons(icons)
 
 
