@@ -1,4 +1,10 @@
-#!/usr/bin/python2.2
+#!/usr/bin/python2.3
+if __name__ == "__main__":
+    import sys
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
+
 
 import pygtk
 pygtk.require("2.0")
